# swgo-psa

This Python package contains pulse-shape analysis functions for [SWGO.](https://www.swgo.org/)

## Resources

- [package documentation](https://fwerner.github.io/swgo-psa/) of the main branch
- [PyPi package](https://pypi.org/project/swgo-psa/) of the last tagged version
- [TestPyPi packages](https://test.pypi.org/project/swgo-psa/#history) of the main branch
